@@ -75,7 +75,7 @@ The framework is structured into the following modules:
 # All Rights Reserved
 
 __name__ = 'lightly'
-__version__ = '1.2.37'
+__version__ = '1.2.47'
 
 import os
 
@@ -123,12 +123,13 @@ else:
     from lightly import transforms
     from lightly import utils
     
-    from lightly.api.version_checking import do_version_check
-
     if os.getenv('LIGHTLY_DID_VERSION_CHECK', 'False') == 'False':
         os.environ['LIGHTLY_DID_VERSION_CHECK'] = 'True'
-
-        try:
-            do_version_check(current_version=__version__)
-        except Exception as e:
-            pass
+        from multiprocessing import current_process
+        if current_process().name == 'MainProcess':
+            from lightly.api.version_checking import is_latest_version, LightlyAPITimeoutException
+            from lightly.openapi_generated.swagger_client.rest import ApiException
+            try:
+                is_latest_version(current_version=__version__)
+            except (ValueError, ApiException, LightlyAPITimeoutException, AttributeError):
+                pass
