@@ -3,7 +3,6 @@ from typing import Dict, List, Optional, Tuple, Union
 
 import tqdm
 import warnings
-import re
 
 from lightly.openapi_generated.swagger_client.models.datasource_config import (
     DatasourceConfig,
@@ -20,9 +19,7 @@ from lightly.openapi_generated.swagger_client.models.datasource_processed_until_
 from lightly.openapi_generated.swagger_client.models.datasource_raw_samples_data import (
     DatasourceRawSamplesData,
 )
-from lightly.openapi_generated.swagger_client.models.datasource_raw_samples_predictions_data import (
-    DatasourceRawSamplesPredictionsData,
-)
+from lightly.openapi_generated.swagger_client import DatasourceConfigVerifyDataErrors
 
 
 class _DatasourcesMixin:
@@ -534,6 +531,52 @@ class _DatasourcesMixin:
             },
             dataset_id=self.dataset_id,
         )
+    
+    def set_obs_config(
+        self,
+        resource_path: str,
+        obs_endpoint: str,
+        obs_access_key_id: str,
+        obs_secret_access_key: str,
+        thumbnail_suffix: Optional[
+            str
+        ] = ".lightly/thumbnails/[filename]_thumb.[extension]",
+        purpose: str = DatasourcePurpose.INPUT_OUTPUT,
+    ) -> None:
+        """Sets the Telekom OBS configuration for the datasource of the current dataset.
+
+        Args:
+            resource_path:
+                OBS url of your dataset. For example, "obs://my_bucket/path/to/my/data".
+            obs_endpoint:
+                OBS endpoint.
+            obs_access_key_id:
+                OBS access key id.
+            obs_secret_access_key:
+                OBS secret access key.
+            thumbnail_suffix:
+                Where to save thumbnails of the images in the dataset, for
+                example ".lightly/thumbnails/[filename]_thumb.[extension]".
+                Set to None to disable thumbnails and use the full images from the
+                datasource instead.
+            purpose:
+                Datasource purpose, determines if datasource is read only (INPUT)
+                or can be written to as well (LIGHTLY, INPUT_OUTPUT).
+                The latter is required when Lightly extracts frames from input videos.
+        """
+        # TODO: Use DatasourceConfigOBS once we switch/update the api generator.
+        self._datasources_api.update_datasource_by_dataset_id(
+            body={
+                "type": "OBS",
+                "fullPath": resource_path,
+                "thumbSuffix": thumbnail_suffix,
+                "obsEndpoint": obs_endpoint,
+                "obsAccessKeyId": obs_access_key_id,
+                "obsSecretAccessKey": obs_secret_access_key,
+                "purpose": purpose,
+            },
+            dataset_id=self.dataset_id,
+        )
 
     def get_prediction_read_url(
         self,
@@ -572,3 +615,48 @@ class _DatasourcesMixin:
             self.dataset_id,
             filename,
         )
+
+    def get_custom_embedding_read_url(
+        self,
+        filename: str,
+    ) -> str:
+        """Returns a read-url for .lightly/embeddings/{filename}.
+
+        Args:
+            filename:
+                Filename for which to get the read-url.
+
+        Returns the read-url. If the file does not exist, a read-url is returned
+        anyways.
+
+        """
+        return self._datasources_api.get_custom_embedding_file_read_url_from_datasource_by_dataset_id(
+            self.dataset_id,
+            filename,
+        )
+
+    def list_datasource_permissions(
+        self,
+    ) -> Dict[str, Union[bool, Optional[DatasourceConfigVerifyDataErrors]]]:
+        """List granted access permissions for the datasource set up with a dataset.
+
+        Returns a string dictionary, with each permission mapped to a boolean value,
+        see the example below. Additionally, there is the ``errors`` key. If there
+        are permission errors it maps to a dictionary from permission name to the
+        error message, otherwise the value is ``None``.
+
+        >>> from lightly.api import ApiWorkflowClient
+        >>> client = ApiWorkflowClient(
+        ...    token="MY_LIGHTLY_TOKEN", dataset_id="MY_DATASET_ID"
+        ... )
+        >>> client.list_datasource_permissions()
+        {'can_list': True,
+         'can_overwrite': True,
+         'can_read': True,
+         'can_write': True,
+         'errors': None}
+
+        """
+        return self._datasources_api.verify_datasource_by_dataset_id(
+            dataset_id=self.dataset_id,
+        )
