@@ -12,13 +12,15 @@ Example:
 import hydra
 import lightly
 
+from lightly.cli._helpers import fix_hydra_arguments
+
 
 def _version_cli():
     version = lightly.__version__
     print(f'lightly version {version}', flush=True)
 
 
-@hydra.main(config_path='config', config_name='config')
+@hydra.main(**fix_hydra_arguments(config_path = 'config', config_name = 'config'))
 def version_cli(cfg):
     """Prints the version of the used lightly package to the terminal.
 
