@@ -5,7 +5,7 @@ lightly version 1.3.0. Instead, use low-level building blocks to build the
 models yourself.
 
 Example implementations for all models can be found here:
-`Model Examples <https://docs.lightly.ai/examples/models.html>`_
+`Model Examples <https://docs.lightly.ai/self-supervised-learning/examples/models.html>`_
 
 The package contains an implementation of the commonly used ResNet and
 adaptations of the architecture which make self-supervised learning simpler.
@@ -28,4 +28,4 @@ from lightly.models.nnclr import NNCLR
 from lightly.models.zoo import ZOO
 from lightly.models.zoo import checkpoints
 
-from lightly.models import utils
\ No newline at end of file
+from lightly.models import utils
